@@ -1,11 +1,16 @@
 #![deny(warnings)]
 
-mod utils;
+#[cfg(feature = "json")]
+pub use serde;
+#[cfg(feature = "json")]
+pub use serde_json;
 
 #[cfg(feature = "cli")]
 pub mod app;
 #[cfg(feature = "cli")]
 pub mod args;
+#[cfg(feature = "cli")]
+pub mod runtime_error;
 
 /// The main program.
 #[cfg(feature = "cli")]
@@ -25,9 +30,9 @@ pub use structopt_utilities;
 pub mod bytes_format;
 pub mod data_tree;
 pub mod fs_tree_builder;
+pub mod json_data;
 pub mod os_string_display;
 pub mod reporter;
-pub mod runtime_error;
 pub mod size;
 pub mod size_getters;
 pub mod status_board;
